@@ -9,8 +9,8 @@ router.register('ptueventrelation', views.PTUEventRelationListViewSet)
 router.register('ptueventassignment', views.PTUEventAssignmentViewSet)
 router.register('pt-app-systems', views.PTAppSystemViewSet)
 router.register('pt-app-system-assignment', views.PTAppSystemAssignmentViewSet)
-router.register('ptusers', views.PTUserListViewSet)
-router.register('ptworkstations', views.PTWorkstationListViewSet)
+router.register('ptusers', views.PTUsersListViewSet)
+router.register('ptworkstations', views.PTWorkstationsListViewSet)
 
 urlpatterns = router.urls
 
