@@ -1,7 +1,7 @@
 from .serializers import PTAppSystemSerializer, PTAppSystemAssignmentSerializer
 from netbox.api.viewsets import NetBoxModelViewSet
 from ..models import PTUEventRelation, PTUEvent, PTUEventAssignment, PTAppSystem, PTAppSystemAssignment, PTUsers, PTWorkstations
-from .serializers import PTUEventRelationSerializer, PTUEventSerializer, PTUEventAssignmentSerializer, PTUserSerializer, PTWorkstationSerializer
+from .serializers import PTUEventRelationSerializer, PTUEventSerializer, PTUEventAssignmentSerializer, PTUsersSerializer, PTWorkstationsSerializer
 from .. import filtersets
 
 
@@ -35,12 +35,12 @@ class PTAppSystemAssignmentViewSet(NetBoxModelViewSet):
     filterset_class = filtersets.PTAppSystemAssignmentFilterSet
 
 
-class PTUserListViewSet(NetBoxModelViewSet):
+class PTUsersListViewSet(NetBoxModelViewSet):
     queryset = PTUsers.objects.prefetch_related('tags')
-    serializer_class = PTUserSerializer
+    serializer_class = PTUsersSerializer
 
 
-class PTWorkstationListViewSet(NetBoxModelViewSet):
+class PTWorkstationsListViewSet(NetBoxModelViewSet):
     queryset = PTWorkstations.objects.prefetch_related('tags')
-    serializer_class = PTWorkstationSerializer
+    serializer_class = PTWorkstationsSerializer
 
