@@ -313,3 +313,42 @@ def del_assignments(sender, **kwargs):
             object_id=instance_id, content_type=content_type_id)
     objs.delete()
 
+
+class PTWorkstationsAssignment(WebhooksMixin, ChangeLoggedModel):
+    content_type = models.ForeignKey(
+        to=ContentType,
+        on_delete=models.CASCADE
+    )
+    object_id = models.PositiveBigIntegerField()
+    object = GenericForeignKey(
+        ct_field='content_type',
+        fk_field='object_id'
+    )
+    app_system = models.ForeignKey(
+        to='ptuevents.PTWorkstations',
+        on_delete=models.PROTECT,
+        related_name='ptworkstations_assignments'
+    )
+
+    clone_fields = ('content_type', 'object_id')
+
+    class Meta:
+        ordering = ['pt_workstations']
+        unique_together = ('content_type', 'object_id',
+                           'pt_workstations')
+
+    def __str__(self):
+        return str(self.app_system)
+
+    def get_absolute_url(self):
+        return reverse('plugins:ptuevents:ptworkstations', args=[self.app_system.pk])
+
+
+@receiver(post_delete, sender=PTUsers, dispatch_uid='del_workstations_assignment')
+def del_assignments(sender, **kwargs):
+    content_type_id = ContentType.objects.get(model='ptworkstations').id
+    instance_id = kwargs.get('instance').id
+    objs = PTWorkstationsAssignment.objects.filter(
+        object_id=instance_id, content_type=content_type_id)
+    objs.delete()
+
