@@ -4,6 +4,8 @@ from django.contrib.contenttypes.models import ContentType
 from django.shortcuts import get_object_or_404
 from django.http import HttpResponseRedirect
 
+from .models import PTWorkstationsAssignment
+
 
 class PTUEventView(generic.ObjectView):
     queryset = models.PTUEvent.objects.all()
@@ -169,6 +171,7 @@ class PTAppSystemAssignmentDeleteView(generic.ObjectDeleteView):
 # PTUsers
 class PTUsersView(generic.ObjectView):
     queryset = models.PTUsers.objects.all()
+
     # template_name = 'ptuevents/ptusers.html'
 
     def get_extra_context(self, request, instance):
@@ -176,20 +179,28 @@ class PTUsersView(generic.ObjectView):
         print(request)
         print(instance.id)
 
-        content_type_id = ContentType.objects.get_for_model(
-            model=models.PTUsers).id
-        PTUEvent_ass = models.PTUEventAssignment.objects.filter(
-            object_id=instance.id, content_type=content_type_id)
+        content_type_id = ContentType.objects.get_for_model(model=models.PTUsers).id
+        PTUEvent_ass = models.PTUEventAssignment.objects.filter(object_id=instance.id, content_type=content_type_id)
         PTUEvents = []
         for r in PTUEvent_ass:
             PTUEvents.append({
                 'assignment_id': r.id,
-                'name': r.ptuevent,
-                'rel': r.relation.name
+                'name'         : r.ptuevent,
+                'rel'          : r.relation.name
             })
 
+        pt_workstations = PTWorkstationsAssignment.objects.filter(object_id=self.context['object'].id,
+                                                                  content_type=content_type_id)
+        PTWorkstations = []
+        for s in pt_workstations:
+            PTWorkstations.append({
+                'id'             : s.id,
+                'pt_workstations': s.pt_workstations})
+            # print(s.__dict__)
+
         return {
-            'PTUEvents': PTUEvents
+            'PTUEvents'      : PTUEvents,
+            'pt_workstations': PTWorkstations
         }
 
 
@@ -206,7 +217,6 @@ class PTUsersEditView(generic.ObjectEditView):
 class PTUsersDeleteView(generic.ObjectDeleteView):
     queryset = models.PTUsers.objects.all()
 
-
 # PTWorkstations
 
 class PTWorkstationsView(generic.ObjectView):
@@ -218,6 +228,11 @@ class PTWorkstationsView(generic.ObjectView):
         print(request)
         print(instance.id)
 
+        pt_workstations_assignments = models.PTWorkstationsAssignment.objects.filter(pt_workstations=instance)
+        pt_workstations_table = tables.PTWorkstationsAssignmentTable(pt_workstations_assignments)
+        pt_workstations_table.columns.hide('pt_workstations')
+        pt_workstations_table.configure(request)
+
         content_type_id = ContentType.objects.get_for_model(
                 model=models.PTWorkstations).id
         PTUEvent_ass = models.PTUEventAssignment.objects.filter(
@@ -231,6 +246,7 @@ class PTWorkstationsView(generic.ObjectView):
             })
 
         return {
+            'assignments_table': pt_workstations_table,
             'PTUEvents': PTUEvents
         }
 
@@ -247,3 +263,43 @@ class PTWorkstationsEditView(generic.ObjectEditView):
 
 class PTWorkstationsDeleteView(generic.ObjectDeleteView):
     queryset = models.PTWorkstations.objects.all()
+
+
+class PTWorkstationsAssignmentEditView(generic.ObjectEditView):
+    queryset = models.PTWorkstationsAssignment.objects.all()
+    form = forms.PTWorkstationsAssignmentForm
+    template_name = 'ptuevents/ptworkstations_assignment_edit.html'
+
+    def alter_object(self, instance, request, args, kwargs):
+        if not instance.pk:
+            # Assign the object based on URL kwargs
+            content_type = get_object_or_404(
+                ContentType, pk=request.GET.get('content_type'))
+            instance.object = get_object_or_404(
+                content_type.model_class(), pk=request.GET.get('object_id'))
+        return instance
+
+    def get_extra_addanother_params(self, request):
+        return {
+            'content_type': request.GET.get('content_type'),
+            'object_id': request.GET.get('object_id'),
+        }
+
+    def post(self, request, *args, **kwargs):
+        form = forms.PTWorkstationsAssignmentForm(request.POST)
+        if form.is_valid():
+            content_type_id = request.GET.get('content_type', -1)
+            object_id = request.GET.get('object_id', -1)
+            s = form.cleaned_data['pt_workstations']
+            qs = models.PTWorkstationsAssignment.objects.filter(
+                content_type=content_type_id, object_id=object_id, pt_workstations=s.id)
+            if qs.exists():
+                redirect_url = request.GET.get('return_url', '/')
+                return HttpResponseRedirect(redirect_url)
+
+        return super().post(request, *args, **kwargs)
+
+
+class PTWorkstationsAssignmentDeleteView(generic.ObjectDeleteView):
+    queryset = models.PTWorkstationsAssignment.objects.all()
+
